..
    Copyright (C) 2019-2020 CERN.
    Copyright (C) 2019 Northwestern University.

    Invenio-Cli is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.


API Docs
========

CLI
---

.. automodule:: invenio_cli.cli
   :members:


Commands
--------

.. automodule:: invenio_cli.commands
   :members:


Helpers
-------

.. automodule:: invenio_cli.helpers
   :members:
